@@ -272,7 +272,7 @@ void SvgRectsCache::dropImageFromCache(const QString &path)
     QMetaObject::invokeMethod(m_configSyncTimer, qOverload<>(&QTimer::start));
 }
 
-QList<QSize> SvgRectsCache::sizeHintsForId(const QString &path, const QString &id)
+QList<QSizeF> SvgRectsCache::sizeHintsForId(const QString &path, const QString &id)
 {
     const QString pathId = path % id;
 
@@ -280,7 +280,7 @@ QList<QSize> SvgRectsCache::sizeHintsForId(const QString &path, const QString &i
     if (it == m_sizeHintsForId.constEnd()) {
         KConfigGroup imageGroup(m_svgElementsCache, path);
         const QStringList &encoded = imageGroup.readEntry(id, QStringList());
-        QList<QSize> sizes;
+        QList<QSizeF> sizes;
         for (const auto &token : encoded) {
             const auto &parts = token.split(QLatin1Char('x'));
             if (parts.size() != 2) {
@@ -298,10 +298,10 @@ QList<QSize> SvgRectsCache::sizeHintsForId(const QString &path, const QString &i
     return *it;
 }
 
-void SvgRectsCache::insertSizeHintForId(const QString &path, const QString &id, const QSize &size)
+void SvgRectsCache::insertSizeHintForId(const QString &path, const QString &id, const QSizeF &size)
 {
     // TODO: need to make this more efficient
-    auto sizeListToString = [](const QList<QSize> &list) {
+    auto sizeListToString = [](const QList<QSizeF> &list) {
         QString ret;
         for (const auto &s : list) {
             ret += QString::number(s.width()) % QLatin1Char('x') % QString::number(s.height()) % QLatin1Char(',');
@@ -477,11 +477,6 @@ bool SvgPrivate::setImagePath(const QString &imagePath)
     bool updateNeeded = true; //! path.isEmpty() || !themePath.isEmpty();
 
     QObject::disconnect(imageSetChangedConnection);
-    if (isThemed && !themed && s_systemColorsCache) {
-        // catch the case where we weren't themed, but now we are, and the colors cache was set up
-        // ensure we are not connected to that theme previously
-        QObject::disconnect(s_systemColorsCache.data(), nullptr, q, nullptr);
-    }
 
     themed = isThemed;
     path.clear();
@@ -558,21 +553,6 @@ ImageSet *SvgPrivate::actualImageSet()
     return theme.data();
 }
 
-ImageSet *SvgPrivate::cacheAndColorsImageSet()
-{
-    if (themed) {
-        return actualImageSet();
-    } else {
-        // use a separate cache source for unthemed svg's
-        if (!s_systemColorsCache) {
-            // FIXME: reference count this, so that it is deleted when no longer in use
-            s_systemColorsCache = new KSvg::ImageSet(QStringLiteral("internal-system-colors"));
-        }
-
-        return s_systemColorsCache.data();
-    }
-}
-
 QPixmap SvgPrivate::findInCache(const QString &elementId, qreal ratio, const QSizeF &s)
 {
     QSize size;
@@ -581,7 +561,7 @@ QPixmap SvgPrivate::findInCache(const QString &elementId, qreal ratio, const QSi
     // Look at the size hinted elements and try to find the smallest one with an
     // identical aspect ratio.
     if (s.isValid() && !elementId.isEmpty()) {
-        const QList<QSize> elementSizeHints = SvgRectsCache::instance()->sizeHintsForId(path, elementId);
+        const QList<QSizeF> elementSizeHints = SvgRectsCache::instance()->sizeHintsForId(path, elementId);
 
         if (!elementSizeHints.isEmpty()) {
             QSizeF bestFit(-1, -1);
@@ -616,8 +596,7 @@ QPixmap SvgPrivate::findInCache(const QString &elementId, qreal ratio, const QSi
     const QString id = cachePath(actualElementId, size);
 
     QPixmap p;
-    if (cacheRendering && lastModified == SvgRectsCache::instance()->lastModifiedTimeFromCache(path)
-        && cacheAndColorsImageSet()->d->findInCache(id, p, lastModified)) {
+    if (cacheRendering && lastModified == SvgRectsCache::instance()->lastModifiedTimeFromCache(path) && actualImageSet()->d->findInCache(id, p, lastModified)) {
         p.setDevicePixelRatio(ratio);
         // qCDebug(LOG_PLASMA) << "found cached version of " << id << p.size();
         return p;
@@ -644,7 +623,7 @@ QPixmap SvgPrivate::findInCache(const QString &elementId, qreal ratio, const QSi
     p.setDevicePixelRatio(ratio);
 
     if (cacheRendering) {
-        cacheAndColorsImageSet()->d->insertIntoCache(id, p, QString::number((qint64)q, 16) % QLatin1Char('_') % actualElementId);
+        actualImageSet()->d->insertIntoCache(id, p, QString::number((qint64)q, 16) % QLatin1Char('_') % actualElementId);
     }
 
     SvgRectsCache::instance()->updateLastModified(path, lastModified);
@@ -671,11 +650,11 @@ void SvgPrivate::createRenderer()
     QString styleSheet;
     if (!colorOverrides.isEmpty()) {
         if (stylesheetOverride.isEmpty()) {
-            stylesheetOverride = cacheAndColorsImageSet()->d->svgStyleSheet(q);
+            stylesheetOverride = actualImageSet()->d->svgStyleSheet(q);
         }
         styleSheet = stylesheetOverride;
     } else {
-        styleSheet = cacheAndColorsImageSet()->d->svgStyleSheet(q);
+        styleSheet = actualImageSet()->d->svgStyleSheet(q);
     }
 
     styleCrc = qChecksum(QByteArrayView(styleSheet.toUtf8().constData(), styleSheet.size()));
@@ -894,18 +873,11 @@ Svg::~Svg()
 
 void Svg::setDevicePixelRatio(qreal ratio)
 {
-    // be completely integer for now
-    // devicepixelratio is always set integer in the svg, so needs at least 192dpi to double up.
-    //(it needs to be integer to have lines contained inside a svg piece to keep being pixel aligned)
-    if (floor(d->devicePixelRatio) == floor(ratio)) {
-        return;
-    }
-
     if (FrameSvg *f = qobject_cast<FrameSvg *>(this)) {
         f->clearCache();
     }
 
-    d->devicePixelRatio = floor(ratio);
+    d->devicePixelRatio = ratio;
 
     Q_EMIT repaintNeeded();
 }
@@ -933,7 +905,7 @@ QImage Svg::image(const QSize &size, const QString &elementID)
 void Svg::paint(QPainter *painter, const QPointF &point, const QString &elementID)
 {
     Q_ASSERT(painter->device());
-    const int ratio = painter->device()->devicePixelRatio();
+    const qreal ratio = painter->device()->devicePixelRatio();
     QPixmap pix((elementID.isNull() || d->multipleImages) ? d->findInCache(elementID, ratio, size()) : d->findInCache(elementID, ratio));
 
     if (pix.isNull()) {
@@ -951,16 +923,16 @@ void Svg::paint(QPainter *painter, int x, int y, const QString &elementID)
 void Svg::paint(QPainter *painter, const QRectF &rect, const QString &elementID)
 {
     Q_ASSERT(painter->device());
-    const int ratio = painter->device()->devicePixelRatio();
+    const qreal ratio = painter->device()->devicePixelRatio();
     QPixmap pix(d->findInCache(elementID, ratio, rect.size()));
 
-    painter->drawPixmap(QRectF(rect.topLeft(), rect.size()), pix, QRectF(QPointF(0, 0), pix.size()));
+    painter->drawPixmap(rect, pix, QRect(QPoint(0, 0), pix.size()));
 }
 
 void Svg::paint(QPainter *painter, int x, int y, int width, int height, const QString &elementID)
 {
     Q_ASSERT(painter->device());
-    const int ratio = painter->device()->devicePixelRatio();
+    const qreal ratio = painter->device()->devicePixelRatio();
     QPixmap pix(d->findInCache(elementID, ratio, QSizeF(width, height)));
     painter->drawPixmap(x, y, pix, 0, 0, pix.size().width(), pix.size().height());
 }
@@ -1153,7 +1125,7 @@ QColor Svg::color(StyleSheetColor colorName) const
     if (it != d->colorOverrides.constEnd()) {
         return *it;
     }
-    return d->cacheAndColorsImageSet()->d->namedColor(colorName, this);
+    return d->actualImageSet()->d->namedColor(colorName, this);
 }
 
 void Svg::setColor(StyleSheetColor colorName, const QColor &color)
